import { CdpClient } from '../../CdpConnection.js';
import { RealmStorage } from '../script/realmStorage.js';
import { IEventManager } from '../events/EventManager.js';
import { Script } from '../../../protocol/protocol.js';
import { Deferred } from '../../../utils/deferred.js';
import { PreloadScriptStorage } from './PreloadScriptStorage.js';
export declare class CdpTarget {
    #private;
    static create(targetId: string, parentTargetId: string | null, cdpClient: CdpClient, cdpSessionId: string, realmStorage: RealmStorage, eventManager: IEventManager, preloadScriptStorage: PreloadScriptStorage): CdpTarget;
    private constructor();
    /** Returns a promise that resolves when the target is unblocked. */
    get targetUnblocked(): Deferred<void>;
    get targetId(): string;
    get cdpClient(): CdpClient;
    /**
     * Needed for CDP escape path.
     */
    get cdpSessionId(): string;
    /**
     * Enables the Network domain (creates NetworkProcessor on the target's cdp
     * client) if it is not enabled yet.
     */
    enableNetworkDomain(): Promise<void>;
    /** Loads all top-level and parent preload scripts. */
    loadPreloadScripts(): Promise<void>;
    /**
     * Issues `Page.addScriptToEvaluateOnNewDocument` CDP command with the given
     * script source in evaluated form and world name / sandbox.
     *
     * @return The CDP preload script ID.
     */
    addPreloadScript(scriptSource: string, sandbox?: string): Promise<Script.PreloadScript>;
    /**
     * Issues `Page.removeScriptToEvaluateOnNewDocument` CDP command with the
     * given CDP preload script ID.
     */
    removePreloadScript(cdpPreloadScriptId: string): Promise<void>;
}
